export declare enum NodeType {
    Text = 0,
    ChannelLink = 1,
    UserLink = 2,
    URL = 3,
    Command = 4,
    Emoji = 5,
    PreText = 6,
    Code = 7,
    Italic = 8,
    Bold = 9,
    Strike = 10,
    Quote = 11,
    Root = 12
}
export declare type Node = Text | ChannelLink | UserLink | URL | Command | Emoji | PreText | Code | Italic | Bold | Strike | Quote | Root;
interface NodeBase {
    type: NodeType;
}
export interface Text extends NodeBase {
    type: NodeType.Text;
    text: string;
}
export interface ChannelLink extends NodeBase {
    type: NodeType.ChannelLink;
    channelID: string;
    label?: Node[];
}
export interface UserLink extends NodeBase {
    type: NodeType.UserLink;
    userID: string;
    label?: Node[];
}
export interface URL extends NodeBase {
    type: NodeType.URL;
    url: string;
    label?: Node[];
}
export interface Command extends NodeBase {
    type: NodeType.Command;
    name: string;
    arguments: string[];
    label?: Node[];
}
export interface Emoji extends NodeBase {
    type: NodeType.Emoji;
    name: string;
    variation?: string;
}
export interface PreText extends NodeBase {
    type: NodeType.PreText;
    text: string;
}
export interface Code extends NodeBase {
    type: NodeType.Code;
    text: string;
}
export interface Italic extends NodeBase {
    type: NodeType.Italic;
    children: Node[];
}
export interface Bold extends NodeBase {
    type: NodeType.Bold;
    children: Node[];
}
export interface Strike extends NodeBase {
    type: NodeType.Strike;
    children: Node[];
}
export interface Quote extends NodeBase {
    type: NodeType.Quote;
    children: Node[];
}
export interface Root extends NodeBase {
    type: NodeType.Root;
    children: Node[];
}
export {};
